I'd kiss you as the lights went out

{interactive slug="binary-cards" type="whole-page" parameters="digits=5&start=BBBBB" thumbnail="binarycards.png" text="true"}

Swaying as the room burned down

{interactive end}

I'd hold you as the water rushes in

{interactive slug="arrows" text="true" type="whole-page" parameters="digits=5&start=BBBBB"}

If I could dance with you again

{interactive end}

I'd kiss you as the lights went out

{interactive text="true" slug="flying-boxes" type="whole-page"}

Swaying as the room burned down

{interactive end}

I'd hold you as the water rushes in
